/*
 * compiler program copyright (C) 2009 - 2012 H.Niwa
 */

/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __COMPILER_H__
#define __COMPILER_H__

extern int compmodule(Context* cx, Node* goalscar, Node* goalscdr, 
				Node* goals, List* module, int& r);

extern int CompCheckReserved(Context* cx, Node* goalscar, List* module);
extern int CompGetVar(Context* cx, Node* goalscar, List* module);
extern int CompAddVar(Context* cx, Node* goalscar, List* module);
extern int CompCheckVar(Context* cx, Node* goalscar, List* module);
extern int CompNewFunc(Context* cx, Node* goalscar, List* module);
extern int CompEndFunc(Context* cx, Node* goalscar, List* module);
extern int CompStructRecord(Context* cx, Node* goalscar, List* module);


#endif

